@@ -75,7 +75,6 @@ enum
 #define BreathRegulator	SpecialF[3]				// timer for fire spewing regulation
 
 #define	ButtTimer			SpecialF[0]			// timer for on butt
-#define FireParticleMagicNum SpecialL[2]
 #define FireTimer 			SpecialF[1]
 
 
@@ -609,7 +608,7 @@ Boolean isVisible;
 
 Boolean BallHitFireAnt(ObjNode *me, ObjNode *enemy)
 {
-long			pg,i;
+int32_t			pg;
 TQ3Vector3D		delta;
 Boolean	killed = false;
 
@@ -623,7 +622,7 @@ Boolean	killed = false;
 
 				/* white sparks */
 					
-		pg = NewParticleGroup(	0,							// magic num
+		pg = NewParticleGroup(
 								PARTICLE_TYPE_FALLINGSPARKS,	// type
 								PARTICLE_FLAGS_BOUNCE|PARTICLE_FLAGS_HOT,		// flags
 								500,						// gravity
@@ -635,7 +634,7 @@ Boolean	killed = false;
 		
 		if (pg != -1)
 		{
-			for (i = 0; i < 50; i++)
+			for (int i = 0; i < 50; i++)
 			{
 				delta.x = (RandomFloat()-.5f) * 1000.0f;
 				delta.y = (RandomFloat()-.5f) * 1000.0f;
@@ -646,7 +645,7 @@ Boolean	killed = false;
 		
 					/* fire sparks */
 					
-		pg = NewParticleGroup(	0,							// magic num
+		pg = NewParticleGroup(
 								PARTICLE_TYPE_FALLINGSPARKS,	// type
 								PARTICLE_FLAGS_BOUNCE|PARTICLE_FLAGS_HOT,		// flags
 								500,						// gravity
@@ -658,7 +657,7 @@ Boolean	killed = false;
 		
 		if (pg != -1)
 		{
-			for (i = 0; i < 50; i++)
+			for (int i = 0; i < 50; i++)
 			{
 				delta.x = (RandomFloat()-.5f) * 500.0f;
 				delta.y = (RandomFloat()-.4f) * 500.0f;
@@ -765,11 +764,9 @@ static void UpdateFireAnt(ObjNode *theNode, Boolean updateFlame)
 	{
 		if (!(theNode->StatusBits & STATUS_BIT_ISCULLED))		// only update fire if is not culled
 		{
-			if ((theNode->ParticleGroup == -1) || (!VerifyParticleGroupMagicNum(theNode->ParticleGroup, theNode->FireParticleMagicNum)))
+			if (!VerifyParticleGroup(theNode->ParticleGroup))
 			{
-				theNode->FireParticleMagicNum = MyRandomLong();			// generate a random magic num
-				
-				theNode->ParticleGroup = NewParticleGroup(	theNode->FireParticleMagicNum,	// magic num
+				theNode->ParticleGroup = NewParticleGroup(
 																PARTICLE_TYPE_GRAVITOIDS,	// type
 																PARTICLE_FLAGS_HOT,			// flags
 																0,							// gravity
@@ -778,7 +775,6 @@ static void UpdateFireAnt(ObjNode *theNode, Boolean updateFlame)
 																1.0,						// decay rate
 																0,							// fade rate
 																PARTICLE_TEXTURE_FIRE);		// texture
-
 			}
 
 			if (theNode->ParticleGroup != -1)
@@ -861,10 +857,10 @@ long		i;
 		
 					/* MAKE GROUP */
 					
-	if (theNode->BreathParticleGroup == -1)
+	if (!VerifyParticleGroup(theNode->BreathParticleGroup))
 	{
-new_pgroup:	
-		theNode->BreathParticleGroup = NewParticleGroup(0,							// magic num
+new_pgroup:
+		theNode->BreathParticleGroup = NewParticleGroup(
 														PARTICLE_TYPE_FALLINGSPARKS,	// type
 														PARTICLE_FLAGS_BOUNCE|PARTICLE_FLAGS_HURTPLAYER|PARTICLE_FLAGS_HOT,		// flags
 														400,						// gravity
@@ -902,22 +898,3 @@ new_pgroup:
 		}
 	}
 }
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
