@@ -178,7 +178,7 @@ QD3DSetupInputType		viewDef;
 		/* LOAD MODELS */
 		/***************/
 		
-	FSMakeFSSpec(gDataSpec.vRefNum, gDataSpec.parID, ":models:HighScores.3dmf", &file);
+	FSMakeFSSpec(gDataSpec.vRefNum, gDataSpec.parID, ":Models:HighScores.3dmf", &file);
 	LoadGrouped3DMF(&file, MODEL_GROUP_HIGHSCORES);
 
 	
