@@ -651,6 +651,11 @@ static void CleanupLevel(void)
 	gHiveObj = nil;
 	gAntKingObj = nil;
 	gPlayerObj = nil;
+	gCurrentEatingFish = nil;
+	gCurrentEatingBat = nil;
+	gCurrentCarryingFireFly = nil;
+	gCurrentChasingFireFly = nil;
+	gCurrentDragonFly = nil;
 }
 
 
